@@ -2,7 +2,7 @@ package Dancer2::Logger::Fluent;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Moo;
 use Fluent::Logger;
@@ -135,7 +135,7 @@ sub log {
         return;
     }
 
-    if ( @{ $self->{pending} } ) {
+    if ( exists $self->{pending} and @{ $self->{pending} } ) {
         while ( my $pending_message = shift @{ $self->{pending} } ) {
             $self->_fluent->post( $self->tag_prefix, $pending_message );
         }
@@ -154,7 +154,7 @@ Dancer2::Logger::Fluent - Dancer2 logger engine for Fluent::Logger
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
